This Python package contains tools that I am developing/using for manipulating images for my art hobby. In it you will find mathematical tools, filters, etc., that may be of use to you if you are a digital artist for any reason.

As of now there are no plans to create a GUI, but perhaps I will in the futrue, or perhaps someone else will end up creating one using my package ;)

This Package's libraries are free to use for any purpose.

NOTE: Although it is not necessary to write my own methods for handling certain tasks like coordinate system conversions, unit conversions, etc., I do so for the purpose of provding an example (i.e. the real math) of how to actually do it, and to keep my brain refreshed on the topics.

Be your own light to guide yourself out of the darkness! Maybe use the light for a mathematical projection onto the (x,y)-plane :P   AND   then engrave it >:)

Cheers!